﻿Imports Microsoft.Devices.Sensors
Imports Microsoft.Xna.Framework

Partial Public Class MainPage
    Inherits PhoneApplicationPage

    Private motion As Motion

    Public Sub New()
        InitializeComponent()

        If motion.IsSupported Then
            motion = New Motion
            motion.TimeBetweenUpdates = TimeSpan.FromMilliseconds(33)
        End If
    End Sub

    WithEvents _motionEvent As Motion

    Protected Overrides Sub OnNavigatedTo(ByVal args As NavigationEventArgs)
        ' Start the Motion sensor if it's available
        If motion IsNot Nothing Then
            Try
                motion.Start()
            Catch
            End Try
        End If
        MyBase.OnNavigatedTo(args)
    End Sub

    Protected Overrides Sub OnNavigatedFrom(ByVal args As NavigationEventArgs)
        If motion IsNot Nothing Then
            motion.Stop()
        End If
        MyBase.OnNavigatedFrom(args)
    End Sub

    Private Sub OnMotionCurrentValueChanged(ByVal sender As Object, ByVal args As SensorReadingEventArgs(Of MotionReading)) Handles _motionEvent.CurrentValueChanged
        Me.Dispatcher.BeginInvoke(Sub()
                                      Dim attitude As AttitudeReading = args.SensorReading.Attitude
                                      pitchText.Text = (180 * attitude.Pitch / Math.PI).ToString("F0")
                                      rollText.Text = (180 * attitude.Roll / Math.PI).ToString("F0")
                                      yawText.Text = (180 * attitude.Yaw / Math.PI).ToString("F0")
                                      Dim matrix As Matrix = attitude.RotationMatrix
                                      m11Text.Text = matrix.M11.ToString("F3")
                                      m12Text.Text = matrix.M12.ToString("F3")
                                      m13Text.Text = matrix.M13.ToString("F3")
                                      m21Text.Text = matrix.M21.ToString("F3")
                                      m22Text.Text = matrix.M22.ToString("F3")
                                      m23Text.Text = matrix.M23.ToString("F3")
                                      m31Text.Text = matrix.M31.ToString("F3")
                                      m32Text.Text = matrix.M32.ToString("F3")
                                      m33Text.Text = matrix.M33.ToString("F3")
                                      Dim angle As Double = Math.Acos((matrix.M11 + matrix.M22 + matrix.M33 - 1) / 2)
                                      angleText.Text = (180 * angle / Math.PI).ToString("F0")
                                      If angle <> 0 Then
                                          Dim twoSine As Double = 2 * Math.Sin(angle)
                                          Dim x As Double = (matrix.M23 - matrix.M32) / twoSine
                                          Dim y As Double = (matrix.M31 - matrix.M13) / twoSine
                                          Dim z As Double = (matrix.M12 - matrix.M21) / twoSine
                                          axisText.Text = String.Format("({0:F2} {1:F2} {2:F2})", x, y, z)
                                      End If
                                  End Sub)
    End Sub
End Class
