Imports Microsoft.Devices.Sensors

Public Class Game1
    Inherits Microsoft.Xna.Framework.Game

    Private graphics As GraphicsDeviceManager
    Private model As Model
    Private scaleMatrix, worldMatrix, lookatMatrix, viewMatrix, projectionMatrix As Matrix
    Private motion As Motion

    Public Sub New()
        graphics = New GraphicsDeviceManager(Me)
        Content.RootDirectory = "Content"
        TargetElapsedTime = TimeSpan.FromTicks(333333)
        InactiveSleepTime = TimeSpan.FromSeconds(1)

        ' Switch to portrait
        graphics.IsFullScreen = True
        graphics.PreferredBackBufferWidth = 480
        graphics.PreferredBackBufferHeight = 800

        ' Create Motion object
        If motion.IsSupported Then
            motion = New Motion With {.TimeBetweenUpdates = Me.TargetElapsedTime}
        End If
    End Sub

    Protected Overrides Sub OnActivated(ByVal sender As Object, ByVal args As EventArgs)
        If motion IsNot Nothing Then
            Try
                motion.Start()
            Catch
            End Try
        End If
        MyBase.OnActivated(sender, args)
    End Sub

    Protected Overrides Sub OnDeactivated(ByVal sender As Object, ByVal args As EventArgs)
        If motion IsNot Nothing Then
            motion.Stop()
        End If

        MyBase.OnDeactivated(sender, args)
    End Sub

    Protected Overrides Sub Initialize()
        MyBase.Initialize()
    End Sub

    Protected Overrides Sub LoadContent()
        model = Me.Content.Load(Of Model)("Phone Retro Caesar N170910")

        For Each mesh In model.Meshes
            For Each effect As BasicEffect In mesh.Effects
                effect.EnableDefaultLighting()
            Next effect
        Next mesh

        ' Scale matrix
        scaleMatrix = Matrix.CreateScale(0.0001F)

        ' View matrix
        lookatMatrix = Matrix.CreateLookAt(New Vector3(0, 0, 10.0F), Vector3.Zero, Vector3.Up)
        viewMatrix = lookatMatrix

        ' Projection matrix
        Dim aspectRatio As Single = graphics.GraphicsDevice.Viewport.AspectRatio
        projectionMatrix = Matrix.CreatePerspectiveFieldOfView(MathHelper.PiOver4, aspectRatio, 1.0F, 100.0F)
    End Sub

    Protected Overrides Sub Update(ByVal gameTime As GameTime)
        If GamePad.GetState(PlayerIndex.One).Buttons.Back = ButtonState.Pressed Then
            Me.Exit()
        End If

        worldMatrix = scaleMatrix * Matrix.CreateRotationX(MathHelper.PiOver2)

        If motion IsNot Nothing AndAlso motion.IsDataValid Then
            worldMatrix *= motion.CurrentValue.Attitude.RotationMatrix
        End If

        MyBase.Update(gameTime)
    End Sub

    Protected Overrides Sub Draw(ByVal gameTime As GameTime)
        GraphicsDevice.Clear(Color.CornflowerBlue)
        model.Draw(worldMatrix, viewMatrix, projectionMatrix)
        MyBase.Draw(gameTime)
    End Sub
End Class
