﻿Imports Microsoft.Devices.Sensors

Partial Public Class MainPage
    Inherits PhoneApplicationPage

    Private motion As Motion

    Public Sub New()
        InitializeComponent()

        If motion.IsSupported Then
            motion = New Motion
            motion.TimeBetweenUpdates = TimeSpan.FromMilliseconds(33)
        End If
    End Sub

    WithEvents _motionEvent As Motion

    Protected Overrides Sub OnNavigatedTo(ByVal args As NavigationEventArgs)
        If motion IsNot Nothing Then
            Try
                motion.Start()
            Catch
            End Try
        End If

        MyBase.OnNavigatedTo(args)
    End Sub

    Protected Overrides Sub OnNavigatedFrom(ByVal e As NavigationEventArgs)
        If motion IsNot Nothing Then
            motion.Stop()
        End If

        MyBase.OnNavigatedFrom(e)
    End Sub

    Private Sub OnMotionCalibrate(ByVal sender As Object, ByVal args As CalibrationEventArgs) Handles _motionEvent.Calibrate
        Me.Dispatcher.BeginInvoke(Sub() TryCast(Me.Resources("calibrateStoryboard"), Storyboard).Begin())
    End Sub

    Private Sub OnMotionCurrentValueChanged(ByVal sender As Object, ByVal args As SensorReadingEventArgs(Of MotionReading)) Handles _motionEvent.CurrentValueChanged
        Dim attitude As AttitudeReading = args.SensorReading.Attitude

        Me.Dispatcher.BeginInvoke(Sub()
                                      yawValue.Text = (180 * attitude.Yaw / Math.PI).ToString("F0") & "°"
                                      pitchValue.Text = (180 * attitude.Pitch / Math.PI).ToString("F0") & "°"
                                      rollValue.Text = (180 * attitude.Roll / Math.PI).ToString("F0") & "°"
                                      yawRotate.Angle = 180 * attitude.Yaw / Math.PI
                                      If attitude.Pitch <= Math.PI / 2 AndAlso attitude.Pitch >= -Math.PI / 2 Then
                                          pitchPath.Fill = pitchPath.Stroke
                                          pitchEllipse.Center = New Point(ContentPanel.ActualWidth / 2, ContentPanel.ActualHeight * (attitude.Pitch + Math.PI / 2) / Math.PI)
                                      Else
                                          pitchPath.Fill = Nothing
                                          If attitude.Pitch > Math.PI / 2 Then
                                              pitchEllipse.Center = New Point(ContentPanel.ActualWidth / 2, ContentPanel.ActualHeight * (3 * Math.PI / 2 - attitude.Pitch) / Math.PI)
                                          Else
                                              pitchEllipse.Center = New Point(ContentPanel.ActualWidth / 2, ContentPanel.ActualHeight * (-Math.PI / 2 - attitude.Pitch) / Math.PI)
                                          End If
                                      End If
                                      rollEllipse.Center = New Point(ContentPanel.ActualWidth * (attitude.Roll + Math.PI / 2) / Math.PI, ContentPanel.ActualHeight / 2)
                                  End Sub)
    End Sub
End Class
